summaryrefslogtreecommitdiff
path: root/src/account-server/main-account.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/account-server/main-account.cpp')
-rw-r--r--src/account-server/main-account.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/account-server/main-account.cpp b/src/account-server/main-account.cpp
index 209e4a24..fd3037b2 100644
--- a/src/account-server/main-account.cpp
+++ b/src/account-server/main-account.cpp
@@ -42,6 +42,7 @@
#include "net/connectionhandler.hpp"
#include "net/messageout.hpp"
#include "utils/logger.h"
+#include "utils/processorutils.hpp"
#include "utils/stringfilter.h"
// Default options that automake should be able to override.
@@ -176,7 +177,10 @@ void initialize()
config.setValue("dbpass", "");
config.setValue("dbhost", "");
- //Seed the random number generator
+ // Initialize the processor utility functions
+ utils::processor::init();
+
+ // Seed the random number generator
std::srand( time(NULL) );
}